prism.annotate module — prism documentation

# prism.annotate module

`prism.annotate.` `run`(input_fp, output_fp, bed_fps, annotation_names, output_figure_fp=None, dpi=400, width=4, height=4, scale=1, font_family=None)

`prism.annotate.` `scatter_1d`(subclone_assignments, num_subclones, depths, fingerprint_fractions, annotation_names, annotation_mask, width, height, dpi)

  Generate annotated scatterplot for one-dimensional PRISM analysis.

  Parameters: | subclone_assignments (list) – List containing subclone assignment status for each fingerprint epilocus. num_subclones (int) – Number of subclones. depths (list) – List of depths (pattern counts). fingerprint_fractions (list) – List of fingerprint fractions. annotation_names (list) – List of the names of annotations. annotation_mask (list) – List containing annotation status for each fingerprint epilocus. width (float) – Figure width. height (float) – Figure height. dpi (int) – Figure DPI.

`prism.annotate.` `scatter_2d`(subclone_assignments, num_subclones, fingerprint_fractions, annotation_names, annotation_mask, width, height, dpi)

  Generate annotated scatterplot for two-dimensional PRISM analysis.

  Parameters: | subclone_assignments (list) – List containing subclone assignment status for each fingerprint epilocus. num_subclones (int) – Number of subclones. fingerprint_fractions (list) – List of fingerprint fractions. annotation_names (list) – List of the names of annotations. annotation_mask (list) – List containing annotation status for each fingerprint epilocus. width (float) – Figure width. height (float) – Figure height. dpi (int) – Figure DPI.